@@ -26,16 +26,11 @@ Implementation Notes
 * Adafruit's Bus Device library: https://github.com/adafruit/Adafruit_CircuitPython_BusDevice
 
 """
+import struct
 import time
 
 from micropython import const
-
-try:
-    import ustruct as struct
-except ImportError:
-    import struct
-
-import adafruit_bus_device.i2c_device as i2c_device
+from adafruit_bus_device import i2c_device
 
 
 __version__ = "0.0.0-auto.0"
